#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_TWO_SPLIT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_TWO_SPLIT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/two_split.hpp>

#endif
